@@ -27,7 +27,6 @@ class CollectCurated(ElementValidationTask):
         "mtype": None,
         "rotation_matrix": None,
     }
-    input_index_col = luigi.Parameter(default="morph_name")
 
     validation_function = collect
 
@@ -38,20 +37,12 @@ class MType(ElementValidationTask):
     Currently, we only check if the mtype corresponds to the provided list of regex.
     If the list of regex is empty, we let all the morphologies pass (equivalent to skip).
 
-    If they do not, we unvalidate the morphologies.
+    If they do not, we invalidate the morphologies.
     """
 
     output_columns = {"mtype": None}
     validation_function = assign_mtypes
-    mtype_regex = luigi.ListParameter(
-        default=[
-            "L[1-6]_[A-Z]+$",  # ex: L5_BP
-            "L[1-6]_[A-Z]+:[A-C]$",  # ex: L5_TPC:A
-            "L23_[A-Z]+$",  # ex: L23_BP
-            "L23_[A-Z]+:[A-C]$",  # ex: L23_TPC:A
-            "L[1-6]_[A-Z]+-[A-Z]+$",  # ex: L1_NCG-CA
-        ]
-    )
+    mtype_regex = luigi.OptionalListParameter(default=None)
 
     def kwargs(self):
         """ """
