@@ -299,11 +299,17 @@ def test_example_1(example_1, data_dir):
                         "hard_limit_path",
                         "marker_path",
                         "morph_path",
-                        "repair_morph_db_path",
+                        "repair_morph_db_path_asc",
+                        "repair_morph_db_path_h5",
+                        "repair_morph_db_path_swc",
                         "repair_morph_path",
-                        "unravel_morph_db_path",
+                        "unravel_morph_db_path_asc",
+                        "unravel_morph_db_path_h5",
+                        "unravel_morph_db_path_swc",
                         "unravel_morph_path",
-                        "zero_diameter_morph_db_path",
+                        "zero_diameter_morph_db_path_asc",
+                        "zero_diameter_morph_db_path_h5",
+                        "zero_diameter_morph_db_path_swc",
                         "zero_diameter_morph_path",
                         "smooth_morph_path",
                     ]
@@ -318,11 +324,17 @@ def test_example_1(example_1, data_dir):
                         "('CollectAnnotated', 'cut_leaves_path')",
                         "('CollectAnnotated', 'morph_path')",
                         "('FixZeroDiameters', 'morph_path')",
-                        "('MakeRelease', 'repair_morph_db_path')",
+                        "('MakeRelease', 'repair_morph_db_path_asc')",
+                        "('MakeRelease', 'repair_morph_db_path_h5')",
+                        "('MakeRelease', 'repair_morph_db_path_swc')",
                         "('MakeRelease', 'repair_morph_path')",
-                        "('MakeRelease', 'unravel_morph_db_path')",
+                        "('MakeRelease', 'unravel_morph_db_path_asc')",
+                        "('MakeRelease', 'unravel_morph_db_path_h5')",
+                        "('MakeRelease', 'unravel_morph_db_path_swc')",
                         "('MakeRelease', 'unravel_morph_path')",
-                        "('MakeRelease', 'zero_diameter_morph_db_path')",
+                        "('MakeRelease', 'zero_diameter_morph_db_path_asc')",
+                        "('MakeRelease', 'zero_diameter_morph_db_path_h5')",
+                        "('MakeRelease', 'zero_diameter_morph_db_path_swc')",
                         "('MakeRelease', 'zero_diameter_morph_path')",
                         "('PlotRepair', 'cut_leaves_path')",
                         "('PlotRepair', 'morph_path')",
@@ -344,11 +356,17 @@ def test_example_1(example_1, data_dir):
                         "apical_point_path",
                         "cut_leaves_path",
                         "morph_path",
-                        "repair_morph_db_path",
+                        "repair_morph_db_path_asc",
+                        "repair_morph_db_path_h5",
+                        "repair_morph_db_path_swc",
                         "repair_morph_path",
-                        "unravel_morph_db_path",
+                        "unravel_morph_db_path_asc",
+                        "unravel_morph_db_path_h5",
+                        "unravel_morph_db_path_swc",
                         "unravel_morph_path",
-                        "zero_diameter_morph_db_path",
+                        "zero_diameter_morph_db_path_asc",
+                        "zero_diameter_morph_db_path_h5",
+                        "zero_diameter_morph_db_path_swc",
                         "zero_diameter_morph_path",
                         "smooth_morph_path",
                     ],
@@ -384,11 +402,17 @@ def test_example_1(example_1, data_dir):
             "format_data_kwargs": {
                 "replace_pattern": {
                     out_dir_pattern: [
-                        "repair_morph_db_path",
+                        "repair_morph_db_path_asc",
+                        "repair_morph_db_path_h5",
+                        "repair_morph_db_path_swc",
                         "repair_morph_path",
-                        "unravel_morph_db_path",
+                        "unravel_morph_db_path_asc",
+                        "unravel_morph_db_path_h5",
+                        "unravel_morph_db_path_swc",
                         "unravel_morph_path",
-                        "zero_diameter_morph_db_path",
+                        "zero_diameter_morph_db_path_asc",
+                        "zero_diameter_morph_db_path_h5",
+                        "zero_diameter_morph_db_path_swc",
                         "zero_diameter_morph_path",
                     ]
                 }
